==> pgmarket-1.4.2.tar.gz: pgmarket-1.4.2/DOCS/layersmenu-example/layersmenu-header.inc.php <==
<!-- Layers Menu (c) 2001 Marco Pratesi <pratesi@telug.it> -->

<?
$treefile = "layersmenu.txt";

$abscissa_step = 140;			// step for the left boundaries of layers
$abscissa_stepx5 = $abscissa_step*5;
$ordinata_step = 15;			// estimated value of the number of pixels between links on a layer
$ordinata[2] = 15-$ordinata_step;	// to choose the vertical coordinate start offset for the layers
$rightarrow = " &middot;&middot;&middot;&gt;";
?>

<script language="JavaScript">
<!--
NS4 = (document.layers) ? 1 : 0;
IE4 = (document.all) ? 1 : 0;
DOM = (document.getElementById) ? 1 : 0;
var gotlayers = 0;
var lastbutton='top';
// -->
</script>

<script language="JavaScript1.2">
<!--

function popUp(menuName,on) {
	if (gotlayers) {
		if (on) {
			moveLayers();
			if (NS4) {
				document.layers[menuName].visibility = "show";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "visible";
			} else {
				document.all[menuName].style.visibility = "visible";
			}
		} else {
			if (NS4) {
				document.layers[menuName].visibility = "hide";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "hidden";
			} else {
				document.all[menuName].style.visibility = "hidden";
			}
		}
	}
}

<?

/* **************************************************************** */
/* Taken from PgMarket (GNU GPL) - Marco Pratesi - pratesi@telug.it */
/* **************************************************************** */

function string_cleanup_js ($string) {
// "cleans up" a string containing "strange" characters

	$string = str_replace(" ", "space", $string);
	$string = str_replace("-", "minus", $string);
	$string = str_replace("!", "exclam", $string);
	$string = str_replace("", "sterling", $string);
	$string = str_replace("$", "dollar", $string);
	$string = str_replace("%", "percent", $string);
	$string = str_replace("&", "ampersand", $string);
	$string = str_replace("/", "slash", $string);
	$string = str_replace("\\", "backslash", $string);
	$string = str_replace("(", "parenleft", $string);
	$string = str_replace(")", "parenright", $string);
	$string = str_replace("[", "bracketleft", $string);
	$string = str_replace("]", "bracketright", $string);
	$string = str_replace("{", "braceleft", $string);
	$string = str_replace("}", "braceright", $string);
	$string = str_replace("?", "question", $string);
	$string = str_replace("*", "asterisk", $string);
	$string = str_replace("@", "at", $string);
	$string = str_replace("", "paragraph", $string);
	$string = str_replace(">", "greater", $string);
	$string = str_replace("<", "lower", $string);
	$string = str_replace("", "degree", $string);
	$string = str_replace("#", "numbersign", $string);
	$string = str_replace("~", "tilde", $string);
	$string = str_replace("`", "grave", $string);
	$string = str_replace("'", "apostrophe", $string);
	$string = str_replace("", "cedilla", $string);

	return $string;

}

/* **************************************************************** */

$moveLayersNS4 = "";
$moveLayersDOM = "";
$moveLayersDef = "";
$shutdown = "";
$firstleveltable = "";

/* ******************************************************************** */
/* Taken from TreeMenu 1.0 (c) 1999 by Bjorge Dijkstra - bjorge@gmx.net */
/* ******************************************************************** */

$maxlevel=0;
$cnt=0;

$fd = fopen($treefile, "r");
if ($fd==0) die("Unable to open file ".$treefile);
while ($buffer = fgets($fd, 4096)) {
	$tree[$cnt][0]=strspn($buffer,".");
	$tmp=rtrim(substr($buffer,$tree[$cnt][0]));
	$node=explode("|",$tmp);
	$tree[$cnt][1]=$node[0];
	$stripped_tree[$cnt] = string_cleanup_js($tree[$cnt][1]) . $cnt;
	$tree[$cnt][2]=$node[1];
	$tree[$cnt][3]=$node[2];
	$tree[$cnt][4]=0;
	if ($tree[$cnt][0] > $maxlevel) $maxlevel=$tree[$cnt][0];
	$cnt++;
}

/* ******************************************************************** */

for ($i=0; $i<$maxlevel; $i++)
	$abscissa[$i] = $i * $abscissa_step;

for ($cnt=1; $cnt<count($tree); $cnt++) {	// this counter scans all nodes
	// assign the layers name to the current hierarchical level,
	// to keep trace of the route leading to the current node on the tree
	$layername[$tree[$cnt][0]] = $stripped_tree[$cnt];

	// assign the starting vertical coordinates for all sublevels
	for ($i=$tree[$cnt][0]+1; $i<$maxlevel; $i++) {
		$ordinata[$i] = $ordinata[$i-1] + 1.5*$ordinata_step;
	}
	// increment the starting vertical coordinate for the actual sublevel
	$ordinata[$tree[$cnt][0]] += $ordinata_step;

	if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// the node is not a leaf, hence it has at least a child
		// prepare the popUp function related to the children
		echo "function popUp" . $stripped_tree[$cnt] . "() {\n" . "shutdown();\n";
		for ($i=2; $i<=$tree[$cnt][0]; $i++)
			echo "popUp('" . $layername[$i] . "',true);\n";
		echo "}\n";

		// geometrical parameters are assigned to the new layer, related to the above mentioned children
		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.width = " . $abscissa_step . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelTop = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelWidth = " . $abscissa_step . ";\n";

		// the new layer is accounted for in the shutdown() function
		$shutdown .= "popUp('" . $stripped_tree[$cnt] . "',false);\n"; 
	}

	if ($tree[$cnt][0] > 2) {	// the hierarchical level is > 2, hence the current node is not a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
/* */
		$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\"";
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
/* */
/*
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"#\" onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
*/
	}

	if ($tree[$cnt][0] == 2) {	// the hierarchical level is = 2, hence the current node is a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
//			$firstleveltable .= "<a href=\"#\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"shutdown();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
	}

}	// end of the "for" cycle scanning all nodes

$shutdown = "function shutdown() {\n" . $shutdown . "}\n" . "if (NS4) {\ndocument.onmousedown = function() { shutdown(); }\n} else {\ndocument.onclick = function() { shutdown(); } \n}\n";

?>

function moveLayers() {
if (gotlayers) {
if (NS4) {
<?=$moveLayersNS4?>
} else if (DOM) {
<?=$moveLayersDOM?>
} else {
<?=$moveLayersDef?>
}}}
<?=$shutdown?>

// -->
</script>

==> pgmarket-1.4.4.tar.gz: pgmarket-1.4.4/DOCS/layersmenu-example/layersmenu-header.inc.php <==
<!-- Layers Menu (c) 2001 Marco Pratesi <pratesi@telug.it> -->

<?
$treefile = "layersmenu.txt";

$abscissa_step = 140;			// step for the left boundaries of layers
$abscissa_stepx5 = $abscissa_step*5;
$ordinata_step = 15;			// estimated value of the number of pixels between links on a layer
$ordinata[1] = 15-$ordinata_step;	// to choose the vertical coordinate start offset for the layers
$rightarrow = " &middot;&middot;&middot;&gt;";
?>

<script language="JavaScript">
<!--
NS4 = (document.layers) ? 1 : 0;
IE4 = (document.all) ? 1 : 0;
DOM = (document.getElementById) ? 1 : 0;
var gotlayers = 0;	// to avoid stupid errors of Microsoft browsers
var lastbutton='top';
// -->
</script>

<script language="JavaScript1.2">
<!--

function popUp(menuName,on) {
	if (gotlayers) {	// to avoid stupid errors of Microsoft browsers
		if (on) {
//			moveLayers();
			if (NS4) {
				document.layers[menuName].visibility = "show";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "visible";
			} else {
				document.all[menuName].style.visibility = "visible";
			}
		} else {
			if (NS4) {
				document.layers[menuName].visibility = "hide";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "hidden";
			} else {
				document.all[menuName].style.visibility = "hidden";
			}
		}
	}
}

<?

$moveLayersNS4 = "";
$moveLayersDOM = "";
$moveLayersDef = "";
$shutdown = "";
$firstleveltable = "";

/* ********************************************************** */
/* Taken from TreeMenu 1.1 - Bjorge Dijkstra (bjorge@gmx.net) */
/* ********************************************************** */
/* with some changes */

$maxlevel=0;
$cnt=1;

$fd = fopen($treefile, "r");
if ($fd==0) die("Unable to open file ".$treefile);
while ($buffer = fgets($fd, 4096)) {
	$tree[$cnt][0]=strspn($buffer,".");
	$tmp=rtrim(substr($buffer,$tree[$cnt][0]));
	$node=explode("|",$tmp);
	$tree[$cnt][1]=$node[0];
	$stripped_tree[$cnt] = "L" . $cnt;
	$tree[$cnt][2]=$node[1];
	$tree[$cnt][3]=$node[2];
	$tree[$cnt][4]=0;
	if ($tree[$cnt][0] > $maxlevel) $maxlevel=$tree[$cnt][0];
	$cnt++;
}
fclose($fd);

/* ******************************************************************** */

for ($i=0; $i<$maxlevel; $i++)
	$abscissa[$i] = $i * $abscissa_step;

for ($cnt=1; $cnt<=count($tree); $cnt++) {	// this counter scans all nodes
	// assign the layers name to the current hierarchical level,
	// to keep trace of the route leading to the current node on the tree
	$layername[$tree[$cnt][0]] = $stripped_tree[$cnt];

	// assign the starting vertical coordinates for all sublevels
	for ($i=$tree[$cnt][0]+1; $i<$maxlevel; $i++) {
		$ordinata[$i] = $ordinata[$i-1] + 1.5*$ordinata_step;
	}
	// increment the starting vertical coordinate for the actual sublevel
	$ordinata[$tree[$cnt][0]] += $ordinata_step;

	if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// the node is not a leaf, hence it has at least a child
		// prepare the popUp function related to the children
		echo "function popUp" . $stripped_tree[$cnt] . "() {\n" . "shutdown();\n";
		for ($i=1; $i<=$tree[$cnt][0]; $i++)
			echo "popUp('" . $layername[$i] . "',true);\n";
		echo "}\n";

		// geometrical parameters are assigned to the new layer, related to the above mentioned children
		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]] . ";\n";
		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.width = " . $abscissa_step . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelTop = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelWidth = " . $abscissa_step . ";\n";

		// the new layer is accounted for in the shutdown() function
		$shutdown .= "popUp('" . $stripped_tree[$cnt] . "',false);\n"; 
	}

	if ($tree[$cnt][0] > 1) {	// the hierarchical level is > 1, hence the current node is not a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
/* */
		$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\"";
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
/* */
/*
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"#\" onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
*/
	}

	if ($tree[$cnt][0] == 1) {	// the hierarchical level is = 1, hence the current node is a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
//			$firstleveltable .= "<a href=\"#\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"shutdown();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
	}

}	// end of the "for" cycle scanning all nodes

$shutdown = "function shutdown() {\n" . $shutdown . "}\n" . "if (NS4) {\ndocument.onmousedown = function() { shutdown(); }\n} else {\ndocument.onclick = function() { shutdown(); } \n}\n";

?>

function moveLayers() {
if (gotlayers) {	// to avoid stupid errors of Microsoft browsers
if (NS4) {
<?=$moveLayersNS4?>
} else if (DOM) {
<?=$moveLayersDOM?>
} else {
<?=$moveLayersDef?>
}}}
<?=$shutdown?>

// -->
</script>
